@@ -88,7 +88,6 @@ namespace eval filexfer {
         filexfer_port filexfer::set_filexfer_port
         filexfer_cookie filexfer::set_filexfer_cookie
         hub_name filexfer::set_hub_name
-        hub_url filexfer::set_hub_url
         session_token filexfer::set_session_token
         hub_template filexfer::set_hub_template
     } {
@@ -159,23 +158,6 @@ proc filexfer::set_hub_template {text} {
     set resources(hubtemplate) $text
 }
 
-# ----------------------------------------------------------------------
-# RESOURCE: hub_url
-# ----------------------------------------------------------------------
-proc filexfer::set_hub_url {text} {
-    variable resources
-    #
-    # BE CAREFUL:  Make sure that we have https:// at the
-    #   start of the hub url, or else we'll get warnings
-    #   about loading secure/non-secure items on IE.
-    #
-    regsub -nocase {^http://} $text https:// text
-    if {![regexp {^https://} $text]} {
-        set text "https://$text"
-    }
-    set resources(huburl) $text
-}
-
 # ----------------------------------------------------------------------
 # RESOURCE: session_token
 # ----------------------------------------------------------------------
